@@ -1,10 +1,7 @@
 package internal
 
 const (
-	// ApplicationName is the non-capitalized name of the application (do not change this)
-	ApplicationName = "syft"
-
 	// JSONSchemaVersion is the current schema version output by the JSON encoder
 	// This is roughly following the "SchemaVer" guidelines for versioning the JSON schema. Please see schema/json/README.md for details on how to increment.
-	JSONSchemaVersion = "7.0.1"
+	JSONSchemaVersion = "11.0.1"
 )
