@@ -6,17 +6,20 @@ import (
 
 	"github.com/go-test/deep"
 
-	"github.com/anchore/syft/syft/formats/common/testutils"
+	"github.com/anchore/syft/syft/formats/internal/testutils"
 )
 
-var updateTableGoldenFiles = flag.Bool("update-table", false, "update the *.golden files for table format")
+var updateSnapshot = flag.Bool("update-table", false, "update the *.golden files for table format")
 
 func TestTableEncoder(t *testing.T) {
 	testutils.AssertEncoderAgainstGoldenSnapshot(t,
-		Format(),
-		testutils.DirectoryInput(t),
-		false,
-		*updateTableGoldenFiles,
+		testutils.EncoderSnapshotTestConfig{
+			Subject:                     testutils.DirectoryInput(t, t.TempDir()),
+			Format:                      Format(),
+			UpdateSnapshot:              *updateSnapshot,
+			PersistRedactionsInSnapshot: true,
+			IsJSON:                      false,
+		},
 	)
 }
 
