@@ -2,7 +2,7 @@ package pkg
 
 import (
 	"github.com/anchore/syft/syft/artifact"
-	"github.com/anchore/syft/syft/source"
+	"github.com/anchore/syft/syft/file"
 )
 
 // Cataloger describes behavior for an object to participate in parsing container image or file system
@@ -12,5 +12,5 @@ type Cataloger interface {
 	// Name returns a string that uniquely describes a cataloger
 	Name() string
 	// Catalog is given an object to resolve file references and content, this function returns any discovered Packages after analyzing the catalog source.
-	Catalog(resolver source.FileResolver) ([]Package, []artifact.Relationship, error)
+	Catalog(resolver file.Resolver) ([]Package, []artifact.Relationship, error)
 }
