@@ -13,6 +13,7 @@ import (
 	"github.com/stretchr/testify/require"
 
 	"github.com/anchore/stereoscope/pkg/imagetest"
+	"github.com/anchore/syft/syft/file"
 	"github.com/anchore/syft/syft/pkg"
 	"github.com/anchore/syft/syft/source"
 )
@@ -239,30 +240,6 @@ func Test_Cataloger_DefaultClassifiers_PositiveCases(t *testing.T) {
 				Metadata:  metadata("redis-binary"),
 			},
 		},
-		{
-			name:       "positive-argocd-2.5.11",
-			fixtureDir: "test-fixtures/classifiers/dynamic/argocd-2.5.11",
-			expected: pkg.Package{
-				Name:      "argocd",
-				Version:   "2.5.11",
-				Type:      "binary",
-				PURL:      "pkg:golang/github.com/argoproj/argo-cd@2.5.11",
-				Locations: locations("argocd"),
-				Metadata:  metadata("argocd"),
-			},
-		},
-		{
-			name:       "positive-argocd-2.6.4",
-			fixtureDir: "test-fixtures/classifiers/dynamic/argocd-2.6.4",
-			expected: pkg.Package{
-				Name:      "argocd",
-				Version:   "2.6.4",
-				Type:      "binary",
-				PURL:      "pkg:golang/github.com/argoproj/argo-cd@2.6.4",
-				Locations: locations("argocd"),
-				Metadata:  metadata("argocd"),
-			},
-		},
 		{
 			name:       "positive-helm-3.11.1",
 			fixtureDir: "test-fixtures/classifiers/dynamic/helm-3.11.1",
@@ -287,66 +264,6 @@ func Test_Cataloger_DefaultClassifiers_PositiveCases(t *testing.T) {
 				Metadata:  metadata("helm"),
 			},
 		},
-		{
-			name:       "positive-kubectl-1.24.11",
-			fixtureDir: "test-fixtures/classifiers/dynamic/kubectl-1.24.11",
-			expected: pkg.Package{
-				Name:      "kubectl",
-				Version:   "1.24.11",
-				Type:      "binary",
-				PURL:      "pkg:golang/k8s.io/kubectl@1.24.11",
-				Locations: locations("kubectl"),
-				Metadata:  metadata("kubectl"),
-			},
-		},
-		{
-			name:       "positive-kubectl-1.25.7",
-			fixtureDir: "test-fixtures/classifiers/dynamic/kubectl-1.25.7",
-			expected: pkg.Package{
-				Name:      "kubectl",
-				Version:   "1.25.7",
-				Type:      "binary",
-				PURL:      "pkg:golang/k8s.io/kubectl@1.25.7",
-				Locations: locations("kubectl"),
-				Metadata:  metadata("kubectl"),
-			},
-		},
-		{
-			name:       "positive-kubectl-1.26.2",
-			fixtureDir: "test-fixtures/classifiers/dynamic/kubectl-1.26.2",
-			expected: pkg.Package{
-				Name:      "kubectl",
-				Version:   "1.26.2",
-				Type:      "binary",
-				PURL:      "pkg:golang/k8s.io/kubectl@1.26.2",
-				Locations: locations("kubectl"),
-				Metadata:  metadata("kubectl"),
-			},
-		},
-		{
-			name:       "positive-kustomize-4.5.7",
-			fixtureDir: "test-fixtures/classifiers/dynamic/kustomize-4.5.7",
-			expected: pkg.Package{
-				Name:      "kustomize",
-				Version:   "4.5.7",
-				Type:      "binary",
-				PURL:      "pkg:golang/sigs.k8s.io/kustomize@4.5.7",
-				Locations: locations("kustomize"),
-				Metadata:  metadata("kustomize"),
-			},
-		},
-		{
-			name:       "positive-kustomize-5.0.0",
-			fixtureDir: "test-fixtures/classifiers/dynamic/kustomize-5.0.0",
-			expected: pkg.Package{
-				Name:      "kustomize",
-				Version:   "5.0.0",
-				Type:      "binary",
-				PURL:      "pkg:golang/sigs.k8s.io/kustomize@5.0.0",
-				Locations: locations("kustomize"),
-				Metadata:  metadata("kustomize"),
-			},
-		},
 		{
 			name:       "positive-redis-4.0.11",
 			fixtureDir: "test-fixtures/classifiers/positive/redis-server-4.0.11",
@@ -714,13 +631,61 @@ func Test_Cataloger_DefaultClassifiers_PositiveCases(t *testing.T) {
 				Metadata:  metadata("ruby-binary"),
 			},
 		},
+		{
+			name:       "positive-consul-1.15.2",
+			fixtureDir: "test-fixtures/classifiers/dynamic/consul-1.15.2",
+			expected: pkg.Package{
+				Name:      "consul",
+				Version:   "1.15.2",
+				Type:      "binary",
+				PURL:      "pkg:golang/github.com/hashicorp/consul@1.15.2",
+				Locations: locations("consul"),
+				Metadata:  metadata("consul-binary"),
+			},
+		},
+		{
+			name:       "positive-nginx-1.25.1",
+			fixtureDir: "test-fixtures/classifiers/positive/nginx-1.25.1",
+			expected: pkg.Package{
+				Name:      "nginx",
+				Version:   "1.25.1",
+				Type:      "binary",
+				PURL:      "pkg:generic/nginx@1.25.1",
+				Locations: locations("nginx"),
+				Metadata:  metadata("nginx-binary"),
+			},
+		},
+		{
+			name:       "positive-nginx-openresty-1.21.4.2",
+			fixtureDir: "test-fixtures/classifiers/positive/nginx-openresty-1.21.4.2",
+			expected: pkg.Package{
+				Name:      "nginx",
+				Version:   "1.21.4",
+				Type:      "binary",
+				PURL:      "pkg:generic/nginx@1.21.4",
+				Locations: locations("nginx"),
+				Metadata:  metadata("nginx-binary"),
+			},
+		},
+		{
+			name:       "positive-bash-5.2.15",
+			fixtureDir: "test-fixtures/classifiers/positive/bash-5.2.15",
+			expected: pkg.Package{
+				Name:      "bash",
+				Version:   "5.2.15",
+				Type:      "binary",
+				PURL:      "pkg:generic/bash@5.2.15",
+				Locations: locations("bash"),
+				Metadata:  metadata("bash-binary"),
+			},
+		},
 	}
 
 	for _, test := range tests {
 		t.Run(test.name, func(t *testing.T) {
 			c := NewCataloger()
 
-			src, err := source.NewFromDirectory(test.fixtureDir)
+			src, err := source.NewFromDirectoryPath(test.fixtureDir)
 			require.NoError(t, err)
 
 			resolver, err := src.FileResolver(source.SquashedScope)
@@ -759,7 +724,7 @@ func Test_Cataloger_DefaultClassifiers_PositiveCases_Image(t *testing.T) {
 			c := NewCataloger()
 
 			img := imagetest.GetFixtureImage(t, "docker-archive", test.fixtureImage)
-			src, err := source.NewFromImage(img, "test-img")
+			src, err := source.NewFromStereoscopeImageObject(img, test.fixtureImage, nil)
 			require.NoError(t, err)
 
 			resolver, err := src.FileResolver(source.SquashedScope)
@@ -789,7 +754,7 @@ func Test_Cataloger_DefaultClassifiers_PositiveCases_Image(t *testing.T) {
 func TestClassifierCataloger_DefaultClassifiers_NegativeCases(t *testing.T) {
 	c := NewCataloger()
 
-	src, err := source.NewFromDirectory("test-fixtures/classifiers/negative")
+	src, err := source.NewFromDirectoryPath("test-fixtures/classifiers/negative")
 	assert.NoError(t, err)
 
 	resolver, err := src.FileResolver(source.SquashedScope)
@@ -800,12 +765,12 @@ func TestClassifierCataloger_DefaultClassifiers_NegativeCases(t *testing.T) {
 	assert.Equal(t, 0, len(actualResults))
 }
 
-func locations(locations ...string) source.LocationSet {
-	var locs []source.Location
+func locations(locations ...string) file.LocationSet {
+	var locs []file.Location
 	for _, s := range locations {
-		locs = append(locs, source.NewLocation(s))
+		locs = append(locs, file.NewLocation(s))
 	}
-	return source.NewLocationSet(locs...)
+	return file.NewLocationSet(locs...)
 }
 
 // metadata paths are: realPath, virtualPath
@@ -829,12 +794,12 @@ func match(classifier string, paths ...string) pkg.ClassifierMatch {
 	}
 	return pkg.ClassifierMatch{
 		Classifier: classifier,
-		Location: source.Location{
-			Coordinates: source.Coordinates{
+		Location: file.NewVirtualLocationFromCoordinates(
+			file.Coordinates{
 				RealPath: realPath,
 			},
-			VirtualPath: virtualPath,
-		},
+			virtualPath,
+		),
 	}
 }
 
@@ -889,10 +854,10 @@ func assertPackagesAreEqual(t *testing.T, expected pkg.Package, p pkg.Package) {
 	if len(failMessages) > 0 {
 		assert.Failf(t, strings.Join(failMessages, "; "), "diff: %s",
 			cmp.Diff(expected, p,
-				cmp.Transformer("Locations", func(l source.LocationSet) []source.Location {
+				cmp.Transformer("Locations", func(l file.LocationSet) []file.Location {
 					return l.ToSlice()
 				}),
-				cmpopts.IgnoreUnexported(pkg.Package{}, source.Location{}),
+				cmpopts.IgnoreUnexported(pkg.Package{}, file.Location{}),
 				cmpopts.IgnoreFields(pkg.Package{}, "CPEs", "FoundBy", "MetadataType", "Type"),
 			))
 	}
@@ -902,22 +867,22 @@ type panicyResolver struct {
 	searchCalled bool
 }
 
-func (p *panicyResolver) FilesByExtension(_ ...string) ([]source.Location, error) {
+func (p *panicyResolver) FilesByExtension(_ ...string) ([]file.Location, error) {
 	p.searchCalled = true
 	return nil, errors.New("not implemented")
 }
 
-func (p *panicyResolver) FilesByBasename(_ ...string) ([]source.Location, error) {
+func (p *panicyResolver) FilesByBasename(_ ...string) ([]file.Location, error) {
 	p.searchCalled = true
 	return nil, errors.New("not implemented")
 }
 
-func (p *panicyResolver) FilesByBasenameGlob(_ ...string) ([]source.Location, error) {
+func (p *panicyResolver) FilesByBasenameGlob(_ ...string) ([]file.Location, error) {
 	p.searchCalled = true
 	return nil, errors.New("not implemented")
 }
 
-func (p *panicyResolver) FileContentsByLocation(_ source.Location) (io.ReadCloser, error) {
+func (p *panicyResolver) FileContentsByLocation(_ file.Location) (io.ReadCloser, error) {
 	p.searchCalled = true
 	return nil, errors.New("not implemented")
 }
@@ -926,34 +891,34 @@ func (p *panicyResolver) HasPath(_ string) bool {
 	return true
 }
 
-func (p *panicyResolver) FilesByPath(_ ...string) ([]source.Location, error) {
+func (p *panicyResolver) FilesByPath(_ ...string) ([]file.Location, error) {
 	p.searchCalled = true
 	return nil, errors.New("not implemented")
 }
 
-func (p *panicyResolver) FilesByGlob(_ ...string) ([]source.Location, error) {
+func (p *panicyResolver) FilesByGlob(_ ...string) ([]file.Location, error) {
 	p.searchCalled = true
 	return nil, errors.New("not implemented")
 }
 
-func (p *panicyResolver) FilesByMIMEType(_ ...string) ([]source.Location, error) {
+func (p *panicyResolver) FilesByMIMEType(_ ...string) ([]file.Location, error) {
 	p.searchCalled = true
 	return nil, errors.New("not implemented")
 }
 
-func (p *panicyResolver) RelativeFileByPath(_ source.Location, _ string) *source.Location {
+func (p *panicyResolver) RelativeFileByPath(_ file.Location, _ string) *file.Location {
 	return nil
 }
 
-func (p *panicyResolver) AllLocations() <-chan source.Location {
+func (p *panicyResolver) AllLocations() <-chan file.Location {
 	return nil
 }
 
-func (p *panicyResolver) FileMetadataByLocation(_ source.Location) (source.FileMetadata, error) {
-	return source.FileMetadata{}, errors.New("not implemented")
+func (p *panicyResolver) FileMetadataByLocation(_ file.Location) (file.Metadata, error) {
+	return file.Metadata{}, errors.New("not implemented")
 }
 
-var _ source.FileResolver = (*panicyResolver)(nil)
+var _ file.Resolver = (*panicyResolver)(nil)
 
 func Test_Cataloger_ResilientToErrors(t *testing.T) {
 	c := NewCataloger()
