@@ -32,6 +32,12 @@ var defaultCandidateAdditions = buildCandidateLookup(
 			candidateKey{PkgName: "spring-core"},
 			candidateAddition{AdditionalProducts: []string{"spring_framework", "springsource_spring_framework"}, AdditionalVendors: []string{"pivotal_software", "springsource", "vmware"}},
 		},
+		{
+			// example image: docker.io/jenkins/jenkins:latest
+			pkg.JavaPkg,
+			candidateKey{PkgName: "spring-security-core"},
+			candidateAddition{AdditionalProducts: []string{"spring_security"}, AdditionalVendors: []string{"vmware"}},
+		},
 		{
 			// example image: docker.io/nuxeo:latest
 			pkg.JavaPkg,
@@ -177,6 +183,11 @@ var defaultCandidateAdditions = buildCandidateLookup(
 			candidateKey{PkgName: "pip"},
 			candidateAddition{AdditionalVendors: []string{"pypa"}},
 		},
+		{
+			pkg.PythonPkg,
+			candidateKey{PkgName: "Django"},
+			candidateAddition{AdditionalVendors: []string{"djangoproject"}},
+		},
 		// Alpine packages
 		{
 			pkg.ApkPkg,
@@ -350,6 +361,11 @@ var defaultCandidateRemovals = buildCandidateRemovalLookup(
 			candidateKey{PkgName: "redis"},
 			candidateRemovals{VendorsToRemove: []string{"redis"}},
 		},
+		{
+			pkg.PythonPkg,
+			candidateKey{PkgName: "kubernetes"},
+			candidateRemovals{ProductsToRemove: []string{"kubernetes"}},
+		},
 		// NPM packages
 		{
 			pkg.NpmPkg,
@@ -371,6 +387,101 @@ var defaultCandidateRemovals = buildCandidateRemovalLookup(
 			candidateKey{PkgName: "docker"},
 			candidateRemovals{VendorsToRemove: []string{"docker"}},
 		},
+		// Java packages
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-builder-support"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-model"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-repository-metadata"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-settings"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-settings-builder"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-resolver-api"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-resolver-connector-basic"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-resolver-impl"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-resolver-named-locks"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-resolver-spi"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-resolver-transport-file"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-resolver-transport-http"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-resolver-transport-wagon"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-resolver-util"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "maven-shared-utils"},
+			candidateRemovals{ProductsToRemove: []string{"maven"}},
+		},
+		{
+			pkg.JavaPkg,
+			candidateKey{PkgName: "gradle-enterprise"},
+			candidateRemovals{
+				ProductsToRemove: []string{"gradle-enterprise"},
+				VendorsToRemove:  []string{"gradle"},
+			},
+		},
+		// Ruby packages
+		{
+			pkg.GemPkg,
+			candidateKey{PkgName: "redis"},
+			candidateRemovals{ProductsToRemove: []string{"redis"}},
+		},
+		{
+			pkg.GemPkg,
+			candidateKey{PkgName: "grpc"},
+			candidateRemovals{ProductsToRemove: []string{"grpc"}},
+		},
 	})
 
 // buildCandidateLookup is a convenience function for creating the defaultCandidateAdditions set
