@@ -2,16 +2,16 @@ package erlang
 
 import (
 	"github.com/anchore/packageurl-go"
+	"github.com/anchore/syft/syft/file"
 	"github.com/anchore/syft/syft/pkg"
-	"github.com/anchore/syft/syft/source"
 )
 
-func newPackage(d pkg.RebarLockMetadata, locations ...source.Location) pkg.Package {
+func newPackage(d pkg.RebarLockMetadata, locations ...file.Location) pkg.Package {
 	p := pkg.Package{
 		Name:         d.Name,
 		Version:      d.Version,
 		Language:     pkg.Erlang,
-		Locations:    source.NewLocationSet(locations...),
+		Locations:    file.NewLocationSet(locations...),
 		PURL:         packageURL(d),
 		Type:         pkg.HexPkg,
 		MetadataType: pkg.RebarLockMetadataType,
