@@ -8,7 +8,7 @@ import (
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
-	"github.com/anchore/syft/syft/source"
+	"github.com/anchore/syft/syft/file"
 )
 
 func Test_parseTarWrappedJavaArchive(t *testing.T) {
@@ -40,8 +40,8 @@ func Test_parseTarWrappedJavaArchive(t *testing.T) {
 				t.Fatalf("failed to open fixture: %+v", err)
 			}
 
-			actualPkgs, _, err := parseTarWrappedJavaArchive(nil, nil, source.LocationReadCloser{
-				Location:   source.NewLocation(test.fixture),
+			actualPkgs, _, err := parseTarWrappedJavaArchive(nil, nil, file.LocationReadCloser{
+				Location:   file.NewLocation(test.fixture),
 				ReadCloser: fixture,
 			})
 			require.NoError(t, err)
