@@ -4,27 +4,28 @@ import (
 	"strings"
 
 	"github.com/anchore/packageurl-go"
+	"github.com/anchore/syft/syft/file"
 	"github.com/anchore/syft/syft/pkg"
-	"github.com/anchore/syft/syft/source"
 )
 
-func newComposerLockPackage(m pkg.PhpComposerJSONMetadata, location ...source.Location) pkg.Package {
+func newComposerLockPackage(m parsedData, indexLocation file.Location) pkg.Package {
 	p := pkg.Package{
 		Name:         m.Name,
 		Version:      m.Version,
-		Locations:    source.NewLocationSet(location...),
+		Locations:    file.NewLocationSet(indexLocation),
+		Licenses:     pkg.NewLicenseSet(pkg.NewLicensesFromLocation(indexLocation, m.License...)...),
 		PURL:         packageURL(m),
 		Language:     pkg.PHP,
 		Type:         pkg.PhpComposerPkg,
 		MetadataType: pkg.PhpComposerJSONMetadataType,
-		Metadata:     m,
+		Metadata:     m.PhpComposerJSONMetadata,
 	}
 
 	p.SetID()
 	return p
 }
 
-func packageURL(m pkg.PhpComposerJSONMetadata) string {
+func packageURL(m parsedData) string {
 	var name, vendor string
 	fields := strings.Split(m.Name, "/")
 	switch len(fields) {
