@@ -7,20 +7,25 @@ import (
 	"io"
 
 	"github.com/anchore/syft/syft/artifact"
+	"github.com/anchore/syft/syft/file"
 	"github.com/anchore/syft/syft/pkg"
 	"github.com/anchore/syft/syft/pkg/cataloger/generic"
-	"github.com/anchore/syft/syft/source"
 )
 
 var _ generic.Parser = parseComposerLock
 
+type parsedData struct {
+	License []string `json:"license"`
+	pkg.PhpComposerJSONMetadata
+}
+
 type composerLock struct {
-	Packages   []pkg.PhpComposerJSONMetadata `json:"packages"`
-	PackageDev []pkg.PhpComposerJSONMetadata `json:"packages-dev"`
+	Packages   []parsedData `json:"packages"`
+	PackageDev []parsedData `json:"packages-dev"`
 }
 
 // parseComposerLock is a parser function for Composer.lock contents, returning "Default" php packages discovered.
-func parseComposerLock(_ source.FileResolver, _ *generic.Environment, reader source.LocationReadCloser) ([]pkg.Package, []artifact.Relationship, error) {
+func parseComposerLock(_ file.Resolver, _ *generic.Environment, reader file.LocationReadCloser) ([]pkg.Package, []artifact.Relationship, error) {
 	pkgs := make([]pkg.Package, 0)
 	dec := json.NewDecoder(reader)
 
@@ -32,8 +37,19 @@ func parseComposerLock(_ source.FileResolver, _ *generic.Environment, reader sou
 			return nil, nil, fmt.Errorf("failed to parse composer.lock file: %w", err)
 		}
 		for _, m := range lock.Packages {
-			pkgs = append(pkgs, newComposerLockPackage(m, reader.Location))
+			pkgs = append(
+				pkgs,
+				newComposerLockPackage(
+					m,
+					reader.Location.WithAnnotation(pkg.EvidenceAnnotationKey, pkg.PrimaryEvidenceAnnotation),
+				),
+			)
 		}
+
+		// TODO: did we omit this on purpose?
+		// for _, m := range lock.PackageDev {
+		//	pkgs = append(pkgs, newComposerLockPackage(m, reader.Location))
+		//}
 	}
 
 	return pkgs, nil, nil
