@@ -2,7 +2,6 @@ package cli
 
 import (
 	"os/exec"
-	"strings"
 	"testing"
 	"time"
 )
@@ -37,10 +36,6 @@ func TestDirectoryScanCompletesWithinTimeout(t *testing.T) {
 		traitFn(t, stdout, stderr, cmd.ProcessState.ExitCode())
 	}
 
-	if t.Failed() {
-		t.Log("STDOUT:\n", stdout)
-		t.Log("STDERR:\n", stderr)
-		t.Log("COMMAND:", strings.Join(cmd.Args, " "))
-	}
+	logOutputOnFailure(t, cmd, stdout, stderr)
 
 }
