@@ -3,15 +3,20 @@ package cli
 import (
 	"fmt"
 	"path/filepath"
-	"strings"
 	"testing"
 )
 
+const (
+	// this is the number of packages that should be found in the image-pkg-coverage fixture image
+	// when analyzed with the squashed scope.
+	coverageImageSquashedPackageCount = 24
+)
+
 func TestPackagesCmdFlags(t *testing.T) {
 	hiddenPackagesImage := "docker-archive:" + getFixtureImage(t, "image-hidden-packages")
 	coverageImage := "docker-archive:" + getFixtureImage(t, "image-pkg-coverage")
 	nodeBinaryImage := "docker-archive:" + getFixtureImage(t, "image-node-binary")
-	//badBinariesImage := "docker-archive:" + getFixtureImage(t, "image-bad-binaries")
+	// badBinariesImage := "docker-archive:" + getFixtureImage(t, "image-bad-binaries")
 	tmp := t.TempDir() + "/"
 
 	tests := []struct {
@@ -37,6 +42,24 @@ func TestPackagesCmdFlags(t *testing.T) {
 				assertSuccessfulReturnCode,
 			},
 		},
+		{
+			name: "quiet-flag-with-logger",
+			args: []string{"packages", "-qvv", "-o", "json", coverageImage},
+			assertions: []traitAssertion{
+				assertJsonReport,
+				assertNoStderr,
+				assertSuccessfulReturnCode,
+			},
+		},
+		{
+			name: "quiet-flag-with-tui",
+			args: []string{"packages", "-q", "-o", "json", coverageImage},
+			assertions: []traitAssertion{
+				assertJsonReport,
+				assertNoStderr,
+				assertSuccessfulReturnCode,
+			},
+		},
 		{
 			name: "multiple-output-flags",
 			args: []string{"packages", "-o", "table", "-o", "json=" + tmp + ".tmp/multiple-output-flag-test.json", coverageImage},
@@ -52,7 +75,7 @@ func TestPackagesCmdFlags(t *testing.T) {
 		//   fail: https://github.com/anchore/syft/runs/4611343586?check_suite_focus=true
 		// For the meantime this test will be commented out, but should be added back in as soon as possible.
 		//
-		//{
+		// {
 		//	name: "regression-survive-bad-binaries",
 		//	// this image has all sorts of rich binaries from the clang-13 test suite that should do pretty bad things
 		//	// to the go cataloger binary path. We should NEVER let a panic stop the cataloging process for these
@@ -65,7 +88,7 @@ func TestPackagesCmdFlags(t *testing.T) {
 		//		assertInOutput("could not parse possible go binary"),
 		//		assertSuccessfulReturnCode,
 		//	},
-		//},
+		// },
 		{
 			name: "output-env-binding",
 			env: map[string]string{
@@ -97,7 +120,7 @@ func TestPackagesCmdFlags(t *testing.T) {
 			name: "squashed-scope-flag",
 			args: []string{"packages", "-o", "json", "-s", "squashed", coverageImage},
 			assertions: []traitAssertion{
-				assertPackageCount(34),
+				assertPackageCount(coverageImageSquashedPackageCount),
 				assertSuccessfulReturnCode,
 			},
 		},
@@ -105,7 +128,7 @@ func TestPackagesCmdFlags(t *testing.T) {
 			name: "squashed-scope-flag-hidden-packages",
 			args: []string{"packages", "-o", "json", "-s", "squashed", hiddenPackagesImage},
 			assertions: []traitAssertion{
-				assertPackageCount(163),
+				assertPackageCount(162),
 				assertNotInOutput("vsftpd"), // hidden package
 				assertSuccessfulReturnCode,
 			},
@@ -114,7 +137,7 @@ func TestPackagesCmdFlags(t *testing.T) {
 			name: "all-layers-scope-flag",
 			args: []string{"packages", "-o", "json", "-s", "all-layers", hiddenPackagesImage},
 			assertions: []traitAssertion{
-				assertPackageCount(164), // packages are now deduplicated for this case
+				assertPackageCount(163), // packages are now deduplicated for this case
 				assertInOutput("all-layers"),
 				assertInOutput("vsftpd"), // hidden package
 				assertSuccessfulReturnCode,
@@ -127,7 +150,7 @@ func TestPackagesCmdFlags(t *testing.T) {
 				"SYFT_PACKAGE_CATALOGER_SCOPE": "all-layers",
 			},
 			assertions: []traitAssertion{
-				assertPackageCount(164), // packages are now deduplicated for this case
+				assertPackageCount(163), // packages are now deduplicated for this case
 				assertInOutput("all-layers"),
 				assertInOutput("vsftpd"), // hidden package
 				assertSuccessfulReturnCode,
@@ -154,7 +177,7 @@ func TestPackagesCmdFlags(t *testing.T) {
 		},
 		{
 			name: "responds-to-package-cataloger-search-options",
-			args: []string{"packages", "-vv"},
+			args: []string{"--help"},
 			env: map[string]string{
 				"SYFT_PACKAGE_SEARCH_UNINDEXED_ARCHIVES": "true",
 				"SYFT_PACKAGE_SEARCH_INDEXED_ARCHIVES":   "false",
@@ -214,7 +237,7 @@ func TestPackagesCmdFlags(t *testing.T) {
 				// the application config in the log matches that of what we expect to have been configured.
 				assertInOutput("parallelism: 2"),
 				assertInOutput("parallelism=2"),
-				assertPackageCount(34),
+				assertPackageCount(coverageImageSquashedPackageCount),
 				assertSuccessfulReturnCode,
 			},
 		},
@@ -225,7 +248,7 @@ func TestPackagesCmdFlags(t *testing.T) {
 				// the application config in the log matches that of what we expect to have been configured.
 				assertInOutput("parallelism: 1"),
 				assertInOutput("parallelism=1"),
-				assertPackageCount(34),
+				assertPackageCount(coverageImageSquashedPackageCount),
 				assertSuccessfulReturnCode,
 			},
 		},
@@ -239,7 +262,7 @@ func TestPackagesCmdFlags(t *testing.T) {
 			assertions: []traitAssertion{
 				assertNotInOutput("secret_password"),
 				assertNotInOutput("secret_key_path"),
-				assertPackageCount(34),
+				assertPackageCount(coverageImageSquashedPackageCount),
 				assertSuccessfulReturnCode,
 			},
 		},
@@ -251,11 +274,7 @@ func TestPackagesCmdFlags(t *testing.T) {
 			for _, traitFn := range test.assertions {
 				traitFn(t, stdout, stderr, cmd.ProcessState.ExitCode())
 			}
-			if t.Failed() {
-				t.Log("STDOUT:\n", stdout)
-				t.Log("STDERR:\n", stderr)
-				t.Log("COMMAND:", strings.Join(cmd.Args, " "))
-			}
+			logOutputOnFailure(t, cmd, stdout, stderr)
 		})
 	}
 }
@@ -263,7 +282,7 @@ func TestPackagesCmdFlags(t *testing.T) {
 func TestRegistryAuth(t *testing.T) {
 	host := "localhost:17"
 	image := fmt.Sprintf("%s/something:latest", host)
-	args := []string{"packages", "-vv", fmt.Sprintf("registry:%s", image)}
+	args := []string{"packages", "-vvv", fmt.Sprintf("registry:%s", image)}
 
 	tests := []struct {
 		name       string
@@ -277,7 +296,7 @@ func TestRegistryAuth(t *testing.T) {
 			assertions: []traitAssertion{
 				assertInOutput("source=OciRegistry"),
 				assertInOutput(image),
-				assertInOutput("no registry credentials configured, using the default keychain"),
+				assertInOutput(fmt.Sprintf("no registry credentials configured for %q, using the default keychain", host)),
 			},
 		},
 		{
@@ -299,7 +318,7 @@ func TestRegistryAuth(t *testing.T) {
 			args: args,
 			env: map[string]string{
 				"SYFT_REGISTRY_AUTH_AUTHORITY": host,
-				"SYFT_REGISTRY_AUTH_TOKEN":     "token",
+				"SYFT_REGISTRY_AUTH_TOKEN":     "my-token",
 			},
 			assertions: []traitAssertion{
 				assertInOutput("source=OciRegistry"),
@@ -308,7 +327,7 @@ func TestRegistryAuth(t *testing.T) {
 			},
 		},
 		{
-			name: "not enough info fallsback to keychain",
+			name: "not enough info fallback to keychain",
 			args: args,
 			env: map[string]string{
 				"SYFT_REGISTRY_AUTH_AUTHORITY": host,
@@ -316,7 +335,7 @@ func TestRegistryAuth(t *testing.T) {
 			assertions: []traitAssertion{
 				assertInOutput("source=OciRegistry"),
 				assertInOutput(image),
-				assertInOutput(`no registry credentials configured, using the default keychain`),
+				assertInOutput(fmt.Sprintf(`no registry credentials configured for %q, using the default keychain`, host)),
 			},
 		},
 		{
@@ -329,6 +348,17 @@ func TestRegistryAuth(t *testing.T) {
 				assertInOutput("insecure-use-http: true"),
 			},
 		},
+		{
+			name: "use tls configuration",
+			args: args,
+			env: map[string]string{
+				"SYFT_REGISTRY_AUTH_TLS_CERT": "place.crt",
+				"SYFT_REGISTRY_AUTH_TLS_KEY":  "place.key",
+			},
+			assertions: []traitAssertion{
+				assertInOutput("using custom TLS credentials from"),
+			},
+		},
 	}
 
 	for _, test := range tests {
@@ -337,11 +367,7 @@ func TestRegistryAuth(t *testing.T) {
 			for _, traitAssertionFn := range test.assertions {
 				traitAssertionFn(t, stdout, stderr, cmd.ProcessState.ExitCode())
 			}
-			if t.Failed() {
-				t.Log("STDOUT:\n", stdout)
-				t.Log("STDERR:\n", stderr)
-				t.Log("COMMAND:", strings.Join(cmd.Args, " "))
-			}
+			logOutputOnFailure(t, cmd, stdout, stderr)
 		})
 	}
 }
